<?php
namespace MascotCoreRoket\Widgets\Testimonials\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Skin_Base as Elementor_Skin_Base;

use MASCOTCOREROKET\Lib;
use MASCOTCOREROKET\CPT\Testimonials\CPT_Testimonials;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style_Current_Theme1 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-cpt-testimonials/general/after_section_end', [ $this, 'register_layout_controls' ] );
	}

	public function get_id() {
		return 'skin-style-current-theme1';
	}


	public function get_title() {
		return __( 'Skin - Style Current Theme1', 'mascot-core-roket' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;

		//Current Background Styling
		$this->start_controls_section(
			'current_content_styling',
			[
				'label' => esc_html__( 'Current Content Styling', 'mascot-core-roket' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'testimonial_skin1_content_bg_color',
			[
				'label' => esc_html__( "Background Color", 'mascot-core-roket' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-block-one .inner-box' => 'background: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'testimonial_skin1_rating_text_color',
			[
				'label' => esc_html__( "Rating Text Color", 'mascot-core-roket' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-block-one .upper-box .rating-box .reason' => 'color: {{VALUE}};'
				]
			]
		);
		$this->end_controls_section();
	}
	
	public function render() {
		$settings = $this->parent->get_settings_for_display();

		$new_cpt_class = CPT_Testimonials::Instance();
		$class_instance =  (array) $new_cpt_class;
		$settings['holder_id'] = roket_get_isotope_holder_ID('testimonials');


		$this->render_output( $class_instance, $settings );
	}

	public function render_output( $class_instance, $settings ) {
		$new_cpt_class = $class_instance;

		$settings['the_query'] = $this->parent->query_posts($new_cpt_class);

		//enqueue css
		$direction_suffix = is_rtl() ? '.rtl' : '';
		wp_enqueue_style( 'tm-testimonial-skin-current-theme1', MASCOT_CORE_ROKET_URL_PATH . 'assets/css/cpt/testimonials/testimonial-skin-current-theme1' . $direction_suffix . '.css' );

		//classes
		$classes = array();
		$classes[] = 'tm-sc-'.$settings['_skin'];
		if( $settings['show_quote_icon'] == 'yes' ) {
			$classes[] = 'testimonial-has-quote-icon';
		}
		if( !empty($settings['custom_quote_icon']) ) {
			$classes[] = 'testimonial-has-custom-quote-icon';
		}
		if( !empty($settings['custom_quote_icon_alignment']) ) {
			$classes[] = $settings['custom_quote_icon_alignment'];
		}
		$classes[] = $settings['custom_css_class'];
		$settings['classes'] = $classes;

		//ptTaxKey
		$settings['ptTaxKey'] = $new_cpt_class['ptTaxKey'];

		//Owl Carousel Data
		$settings['owl_carousel_data_info'] = mascot_core_prepare_owlcarousel_data_from_params( $settings );


		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_roket_get_cpt_shortcode_template_part( 'testimonials', $settings['display_type'], 'testimonials/tpl', $settings, true );

		echo $html;
	}
}
